@@ -1,5 +1,15 @@
 require 'rubygems'
+
 require 'vcr'
+VCR.config do |c|
+  c.default_cassette_options = { :record => :new_episodes }
+  c.cassette_library_dir = 'spec/cassettes'
+  c.stub_with :fakeweb
+end
+
+require 'coveralls'
+Coveralls.wear!
+
 require File.dirname(__FILE__) + '/../lib/oembed'
 
 RSpec.configure do |config|
